@@ -57,6 +57,10 @@ bed_complement <- function(x, genome) {
 
   res <- group_by(res, chrom)
 
+  if (utils::packageVersion("dplyr") < "0.7.99.9000"){
+    res <- update_groups(res)
+  }
+
   res <- complement_impl(res, genome)
 
   res <- bind_rows(res, chroms_no_overlaps)
