@@ -45,12 +45,29 @@ bed_coverage <- function(x, y, ...) {
   if (!is.tbl_interval(y)) y <- as.tbl_interval(y)
 
   x <- bed_sort(x)
-  x <- group_by(x, chrom, add = TRUE)
-
   y <- bed_sort(y)
-  y <- group_by(y, chrom, add = TRUE)
 
-  res <- coverage_impl(x, y)
+  # establish grouping with shared groups (and chrom)
+  groups_xy <- shared_groups(x, y)
+  groups_xy <- unique(as.character(c("chrom", groups_xy)))
+  groups_vars <- rlang::syms(groups_xy)
+
+  # type convert grouping factors to characters if necessary and ungroup
+  x <- convert_factors(x, groups_xy)
+  y <- convert_factors(y, groups_xy)
+
+  x <- group_by(x, !!! groups_vars)
+  y <- group_by(y, !!! groups_vars)
+
+  if (utils::packageVersion("dplyr") < "0.7.99.9000"){
+    x <- update_groups(x)
+    y <- update_groups(y)
+  }
+
+  grp_indexes <- shared_group_indexes(x, y)
+  res <- coverage_impl(x, y,
+                       grp_indexes$x,
+                       grp_indexes$y)
 
   res
 }
