@@ -71,6 +71,10 @@ bed_flank <- function(x, genome, both = 0, left = 0,
 
   if (both) left <- right <- both
 
+  if (utils::packageVersion("dplyr") < "0.7.99.9000"){
+    x <- update_groups(x)
+  }
+
   res <- flank_impl(
     x, genome, both, left,
     right, fraction, strand, trim
