@@ -54,7 +54,6 @@
 #'
 #' @export
 bed_shift <- function(x, genome, size = 0, fraction = 0, trim = FALSE) {
-
   if (!is.tbl_interval(x)) x <- as.tbl_interval(x)
   if (!is.tbl_genome(genome)) genome <- as.tbl_genome(genome)
 
@@ -62,37 +61,53 @@ bed_shift <- function(x, genome, size = 0, fraction = 0, trim = FALSE) {
 
   # shift invervals
   if (!stranded && !fraction) {
-    res <- mutate(x, start = start + size,
-                  end = end + size)
+    res <- mutate(
+      x,
+      start = start + size,
+      end = end + size
+    )
   }
 
   # shift by percent of interval size
-  if (!stranded && fraction){
+  if (!stranded && fraction) {
     res <- mutate(x, .size = end - start)
-    res <- mutate(res, start = start + round(.size * fraction),
-                       end = end + round(.size * fraction))
+    res <- mutate(
+      res,
+      start = start + round(.size * fraction),
+      end = end + round(.size * fraction)
+    )
     res <- select(res, -.size)
   }
 
   # shift by strand
-  if (stranded && !fraction){
-    res <- mutate(x, start = ifelse(strand == "+",
-                       start + size,
-                       start - size),
-                     end = ifelse(strand == "+",
-                       end + size,
-                       end - size))
+  if (stranded && !fraction) {
+    res <- mutate(
+      x,
+      start = ifelse(strand == "+",
+        start + size,
+        start - size
+      ),
+      end = ifelse(strand == "+",
+        end + size,
+        end - size
+      )
+    )
   }
 
   # shift by strand and percent
-  if (stranded && fraction){
+  if (stranded && fraction) {
     res <- mutate(x, .size = end - start)
-    res <- mutate(res, start = ifelse(strand == "+",
-                         start + round(.size * fraction),
-                         start - round(.size * fraction)),
-                       end = ifelse(strand == "+",
-                         end + round(.size * fraction),
-                         end - round(.size * fraction)))
+    res <- mutate(
+      res,
+      start = ifelse(strand == "+",
+        start + round(.size * fraction),
+        start - round(.size * fraction)
+      ),
+      end = ifelse(strand == "+",
+        end + round(.size * fraction),
+        end - round(.size * fraction)
+      )
+    )
     res <- select(res, -.size)
   }
 
