@@ -1,6 +1,6 @@
 // closest.cpp
 //
-// Copyright (C) 2016 - 2017 Jay Hesselberth and Kent Riemondy
+// Copyright (C) 2016 - 2018 Jay Hesselberth and Kent Riemondy
 //
 // This file is part of valr.
 //
@@ -53,8 +53,11 @@ void closest_grouped(ivl_vector_t& vx, ivl_vector_t& vy,
 }
 
 //[[Rcpp::export]]
-DataFrame closest_impl(GroupedDataFrame x, GroupedDataFrame y,
-                       const std::string& suffix_x, const std::string& suffix_y) {
+DataFrame closest_impl(ValrGroupedDataFrame x, ValrGroupedDataFrame y,
+                       IntegerVector grp_idx_x,
+                       IntegerVector grp_idx_y,
+                       const std::string& suffix_x,
+                       const std::string& suffix_y) {
 
   DataFrame df_x = x.data() ;
   DataFrame df_y = y.data() ;
@@ -65,18 +68,13 @@ DataFrame closest_impl(GroupedDataFrame x, GroupedDataFrame y,
   std::vector<int> overlap_sizes ;
   std::vector<int> distance_sizes ;
 
-  // preallocate vector to save some time
-  indices_x.reserve(2e6) ;
-  indices_y.reserve(2e6) ;
-  overlap_sizes.reserve(2e6) ;
-  distance_sizes.reserve(2e6) ;
-
   // set up interval trees for each chromosome and apply closest_grouped
-  GroupApply(x, y, closest_grouped, std::ref(indices_x), std::ref(indices_y),
+  GroupApply(x, y, grp_idx_x, grp_idx_y,
+             closest_grouped, std::ref(indices_x), std::ref(indices_y),
              std::ref(overlap_sizes), std::ref(distance_sizes));
 
-  DataFrame subset_x = DataFrameSubsetVisitors(df_x, df_x.names()).subset(indices_x, "data.frame");
-  DataFrame subset_y = DataFrameSubsetVisitors(df_y, df_y.names()).subset(indices_y, "data.frame");
+  DataFrame subset_x = subset_dataframe(df_x, indices_x) ;
+  DataFrame subset_y = subset_dataframe(df_y, indices_y) ;
 
   DataFrameBuilder out;
   // x names, data
@@ -114,6 +112,6 @@ y <- tibble::tribble(
 suffix_x <- '.x'
 suffix_y <- '.y'
 
-closest_impl(x, y, suffix_x, suffix_y)
+closest_impl(x, y, suffix_x, suffix_y, environment())
 
 */
